@@ -28,6 +28,6 @@
 (greg-testcase "A shell will echo hello" #t
 (lambda ()
   (greg-send "echo hello\n")
-  (greg-recv ("^hello" #t))
+  (greg-recv (" hello" #t))
 ))
 
